Re-exports
pub use sharded::DefaultShardHasher;pub use sharded::ShardHasher;pub use sharded::ShardedCache;pub use sharded::ShardedCacheBase;pub use sharded::ShardedCacheBuilder;pub use sharded::ShardedExpiringCache;pub use sharded::ShardedExpiringCacheBase;pub use sharded::ShardedExpiringCacheBuilder;pub use sharded::ShardedExpiringLruCache;pub use sharded::ShardedExpiringLruCacheBase;pub use sharded::ShardedExpiringLruCacheBuilder;pub use sharded::ShardedLruCache;pub use sharded::ShardedLruCacheBase;pub use sharded::ShardedLruCacheBuilder;pub use sharded::ShardedLruTtlCache;time_storespub use sharded::ShardedLruTtlCacheBase;time_storespub use sharded::ShardedLruTtlCacheBuilder;time_storespub use sharded::ShardedTtlCache;time_storespub use sharded::ShardedTtlCacheBase;time_storespub use sharded::ShardedTtlCacheBuilder;time_stores
Modules
Structs
- Async
Redis Cache async_coreandredis_storeand (redis_smolorredis_tokio) - Cache store backed by redis
- Async
Redis Cache Builder async_coreandredis_storeand (redis_smolorredis_tokio) - Disk
Cache disk_store - Cache store backed by disk
- Disk
Cache Builder disk_store - Expiring
Cache - Size-unbounded cache where each value controls its own expiry via
Expires. - Expiring
Cache Builder - Builder for
ExpiringCache. - Expiring
LruCache - LRU-bounded cache with per-value expiry.
- Expiring
LruCache Builder - Builder for
ExpiringLruCache. - HasEvict
time_stores - Typestate marker for
LruTtlCacheBuilder: eviction callback has been set. - LruCache
- Least Recently Used /
SizedCache - LruCache
Builder - Builder for
LruCache. - LruTtl
Cache time_stores - Timed LRU Cache
- LruTtl
Cache Builder time_stores - Builder for
LruTtlCache. - NoEvict
time_stores - Typestate marker for
LruTtlCacheBuilder: no eviction callback set. - Redis
Cache redis_store - Cache store backed by redis
- Redis
Cache Builder redis_store - Timed
Entry - A cached value paired with its insertion timestamp for TTL tracking.
- TtlCache
time_stores - Cache store bound by time
- TtlCache
Builder time_stores - Builder for
TtlCache. - TtlSorted
Cache time_stores - A cache enforcing time expiration and an optional maximum size. When a maximum size is specified, the values are dropped in the order of expiration date, e.g. the next value to expire is dropped. This cache is intended for high read scenarios to allow for concurrent reads while still enforcing expiration and an optional maximum cache size.
- TtlSorted
Cache Builder time_stores - Builder for
TtlSortedCache. - Unbound
Cache - Default unbounded cache
- Unbound
Cache Builder - Builder for
UnboundCache.
Enums
- Build
Error - Error returned by cache builder
build()methods. - Disk
Cache Build Error disk_store - Disk
Cache Error disk_store - Redis
Cache Build Error redis_store - Redis
Cache Error redis_store
Traits
- Cache
Evict - Trait for cache stores that support explicit eviction of expired entries.
- Expires
- Implemented by values stored in
ExpiringLruCacheandExpiringCacheso the value itself decides when it is stale. Expired values are not returned by lookups and are removed on access:
Type Aliases
- TtlSorted
Cache Error time_stores - Public alias for the internal error type — use this name when matching on errors returned by
TtlSortedCacheoperations (e.g.Cached::cache_try_set).